pspolicy.homes4.base
====================

.. image:: https://travis-ci.org/propertyshelf/pspolicy.homes4.base.png?branch=master
   :target: http://travis-ci.org/propertyshelf/pspolicy.homes4.base

Plone Policy Add-On for the Homes4 sites.
